
# Slot: subject




URI: [biolink:cell_line_to_disease_or_phenotypic_feature_association_subject](https://w3id.org/biolink/vocab/cell_line_to_disease_or_phenotypic_feature_association_subject)


## Domain and Range

[CellLineToDiseaseOrPhenotypicFeatureAssociation](CellLineToDiseaseOrPhenotypicFeatureAssociation.md) &#8594;  <sub>1..1</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [subject](subject.md)

## Children

 *  [cell line as a model of disease association➞subject](cell_line_as_a_model_of_disease_association_subject.md)

## Used by

 * [CellLineToDiseaseOrPhenotypicFeatureAssociation](CellLineToDiseaseOrPhenotypicFeatureAssociation.md)
